==> commerce_stripe_payment_request_button-8.x-1.5.tar.gz: commerce_stripe_payment_request_button/src/Plugin/Commerce/CheckoutFlow/PaymentRequestButtonFlow.php <==
<?php

namespace Drupal\commerce_stripe_payment_request_button\Plugin\Commerce\CheckoutFlow;

use Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowBase;
use Drupal\commerce_payment\Exception\DeclineException;
use Drupal\commerce_payment\Exception\PaymentGatewayException;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;

/**
 * Provides the default multistep checkout flow.
 *
 * @CommerceCheckoutFlow(
 *   id = "payment_request_button_flow",
 *   label = "Commerce Stripe payment request button Flow",
 * )
 */
class PaymentRequestButtonFlow extends CheckoutFlowBase {


  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Creates a new StripeRequestPay object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Symfony\Component\EventDispatcher\EventDispatcherInterface $event_dispatcher
   *   The event dispatcher.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager, EventDispatcherInterface $event_dispatcher, RouteMatchInterface $route_match, ModuleHandlerInterface $module_handler) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $entity_type_manager, $event_dispatcher, $route_match);
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('event_dispatcher'),
      $container->get('current_route_match'),
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getSteps() {
    // Each checkout flow plugin defines its own steps.
    // These two steps are always expected to be present.
    return [
      'payment' => [
        'label' => $this->t('Payment'),
        'next_label' => $this->t('Pay and complete purchase'),
        'has_sidebar' => FALSE,
        'hidden' => TRUE,
      ],
      'complete' => [
        'label' => $this->t('Complete'),
        'next_label' => $this->t('Complete checkout'),
        'has_sidebar' => FALSE,
      ],
    ];
  }


  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $step_id = NULL) {
    $form = parent::buildForm($form, $form_state, $step_id);

    switch ($step_id) {
      case 'payment':
        try {
          // Load payment(s) for this order
          // TODO check if below is proper way to do this, maybe we should load by specific payment
          // gateway and filter by status, find only NEW and not fails transactions
          $payment_gateway = $this->order->get('payment_gateway')->entity;
          $payment_gateway_plugin = $payment_gateway->getPlugin();
          if ($payment_gateway_plugin->pluginId == 'commerce_stripe_payment_request_button') {
            $payment_storage = \Drupal::entityTypeManager()
              ->getStorage('commerce_payment');
            $payments = $payment_storage->loadMultipleByOrder($this->order);
            $payments = array_filter($payments, function ($payment) use ($payment_gateway) {
              return $payment->getPaymentGatewayId() == $payment_gateway->id();
            });
            $payment = reset($payments);
            if ($payment) {
              $payment->setState('completed');
              $payment->save();
            }
          }

          $this->redirectToStep('complete');
        } catch (DeclineException $e) {
          \Drupal::messenger()->addError($e->getMessage());
          throw new NeedsRedirectException(Url::fromRoute('commerce_cart.page')
            ->toString());
        } catch (PaymentGatewayException $e) {
          \Drupal::messenger()->addError($e->getMessage());

          $this->order->get('checkout_flow')->setValue(NULL);
          $this->order->get('checkout_step')->setValue(NULL);
          $this->order->unlock();
          $this->order->save();
          throw new NeedsRedirectException(Url::fromRoute('commerce_cart.page')
            ->toString());
        }
        break;

      case 'complete':
        $form['completion_message']['#theme'] = 'commerce_checkout_completion_message';
        $form['completion_message']['#order_entity'] = $this->order;
        break;
    }

    return $form;
  }
}

==> commerce_stripe_payment_request_button-8.x-2.0.tar.gz: commerce_stripe_payment_request_button/src/Plugin/Commerce/CheckoutFlow/PaymentRequestButtonFlow.php <==
<?php

namespace Drupal\commerce_stripe_payment_request_button\Plugin\Commerce\CheckoutFlow;

use Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowBase;
use Drupal\commerce_payment\Exception\DeclineException;
use Drupal\commerce_payment\Exception\PaymentGatewayException;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;

/**
 * Provides the default multistep checkout flow.
 *
 * @CommerceCheckoutFlow(
 *   id = "payment_request_button_flow",
 *   label = "Commerce Stripe payment request button Flow",
 * )
 */
class PaymentRequestButtonFlow extends CheckoutFlowBase {


  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Creates a new StripeRequestPay object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Symfony\Component\EventDispatcher\EventDispatcherInterface $event_dispatcher
   *   The event dispatcher.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager, EventDispatcherInterface $event_dispatcher, RouteMatchInterface $route_match, ModuleHandlerInterface $module_handler) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $entity_type_manager, $event_dispatcher, $route_match);
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('event_dispatcher'),
      $container->get('current_route_match'),
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getSteps() {
    // Each checkout flow plugin defines its own steps.
    // These two steps are always expected to be present.
    return [
      'payment' => [
        'label' => $this->t('Payment'),
        'next_label' => $this->t('Pay and complete purchase'),
        'has_sidebar' => FALSE,
        'hidden' => TRUE,
      ],
      'complete' => [
        'label' => $this->t('Complete'),
        'next_label' => $this->t('Complete checkout'),
        'has_sidebar' => FALSE,
      ],
    ];
  }


  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $step_id = NULL) {
    $form = parent::buildForm($form, $form_state, $step_id);

    switch ($step_id) {
      case 'payment':
        try {
          // Load payment(s) for this order
          // TODO check if below is proper way to do this, maybe we should load by specific payment
          // gateway and filter by status, find only NEW and not failed transactions
          $payment_gateway = $this->order->get('payment_gateway')->entity;
          $payment_gateway_plugin = $payment_gateway->getPlugin();
          if ($payment_gateway_plugin->pluginId == 'commerce_stripe_payment_request_button') {
            $payment_storage = \Drupal::entityTypeManager()
              ->getStorage('commerce_payment');
            $payments = $payment_storage->loadMultipleByOrder($this->order);
            $payments = array_filter($payments, function ($payment) use ($payment_gateway) {
              return $payment->getPaymentGatewayId() == $payment_gateway->id();
            });
            $payment = reset($payments);
            if ($payment->getState()->getId() == "new") {
              $payment->setState('completed');
              $payment->save();
            }
            else {
              if ($payment->getState()->getId() == "authorization") {
                // You need to manually capture this payment, you can do it with UI or some automatatic scripting
              }
            }
          }
          $this->redirectToStep('complete');
        } catch (DeclineException $e) {
          \Drupal::messenger()->addError($e->getMessage());
          throw new NeedsRedirectException(Url::fromRoute('commerce_cart.page')
            ->toString());
        } catch (PaymentGatewayException $e) {
          \Drupal::messenger()->addError($e->getMessage());

          $this->order->get('checkout_flow')->setValue(NULL);
          $this->order->get('checkout_step')->setValue(NULL);
          $this->order->unlock();
          $this->order->save();
          throw new NeedsRedirectException(Url::fromRoute('commerce_cart.page')
            ->toString());
        }
        break;

      case 'complete':
        $form['completion_message']['#theme'] = 'commerce_checkout_completion_message';
        $form['completion_message']['#order_entity'] = $this->order;
        break;
    }

    return $form;
  }
}
